@@ -46,7 +46,7 @@ import sys
 from typing import TYPE_CHECKING
 
 
-__version__ = "0.33.2"
+__version__ = "0.35.0"
 
 # Alphabetical order of definitions is ensured in tests
 # WARNING: any comment added in this dictionary definition will be lost when
@@ -62,6 +62,12 @@ _SUBMOD_ATTRS = {
         "InferenceEndpointTimeoutError",
         "InferenceEndpointType",
     ],
+    "_jobs_api": [
+        "JobInfo",
+        "JobOwner",
+        "JobStage",
+        "JobStatus",
+    ],
     "_login": [
         "auth_list",
         "auth_switch",
@@ -165,6 +171,7 @@ _SUBMOD_ATTRS = {
         "add_space_variable",
         "auth_check",
         "cancel_access_request",
+        "cancel_job",
         "change_discussion_status",
         "comment_discussion",
         "create_branch",
@@ -175,6 +182,8 @@ _SUBMOD_ATTRS = {
         "create_inference_endpoint_from_catalog",
         "create_pull_request",
         "create_repo",
+        "create_scheduled_job",
+        "create_scheduled_uv_job",
         "create_tag",
         "create_webhook",
         "dataset_info",
@@ -185,6 +194,7 @@ _SUBMOD_ATTRS = {
         "delete_folder",
         "delete_inference_endpoint",
         "delete_repo",
+        "delete_scheduled_job",
         "delete_space_secret",
         "delete_space_storage",
         "delete_space_variable",
@@ -194,6 +204,7 @@ _SUBMOD_ATTRS = {
         "duplicate_space",
         "edit_discussion_comment",
         "enable_webhook",
+        "fetch_job_logs",
         "file_exists",
         "get_collection",
         "get_dataset_tags",
@@ -210,11 +221,14 @@ _SUBMOD_ATTRS = {
         "get_user_overview",
         "get_webhook",
         "grant_access",
+        "inspect_job",
+        "inspect_scheduled_job",
         "list_accepted_access_requests",
         "list_collections",
         "list_datasets",
         "list_inference_catalog",
         "list_inference_endpoints",
+        "list_jobs",
         "list_lfs_files",
         "list_liked_repos",
         "list_models",
@@ -249,12 +263,16 @@ _SUBMOD_ATTRS = {
         "request_space_storage",
         "restart_space",
         "resume_inference_endpoint",
+        "resume_scheduled_job",
         "revision_exists",
         "run_as_future",
+        "run_job",
+        "run_uv_job",
         "scale_to_zero_inference_endpoint",
         "set_space_sleep_time",
         "space_info",
         "super_squash_history",
+        "suspend_scheduled_job",
         "unlike",
         "update_collection_item",
         "update_collection_metadata",
@@ -360,6 +378,10 @@ _SUBMOD_ATTRS = {
         "ImageToTextInput",
         "ImageToTextOutput",
         "ImageToTextParameters",
+        "ImageToVideoInput",
+        "ImageToVideoOutput",
+        "ImageToVideoParameters",
+        "ImageToVideoTargetSize",
         "ObjectDetectionBoundingBox",
         "ObjectDetectionInput",
         "ObjectDetectionOutputElement",
@@ -648,6 +670,10 @@ __all__ = [
     "ImageToTextInput",
     "ImageToTextOutput",
     "ImageToTextParameters",
+    "ImageToVideoInput",
+    "ImageToVideoOutput",
+    "ImageToVideoParameters",
+    "ImageToVideoTargetSize",
     "InferenceApi",
     "InferenceClient",
     "InferenceEndpoint",
@@ -656,6 +682,10 @@ __all__ = [
     "InferenceEndpointTimeoutError",
     "InferenceEndpointType",
     "InferenceTimeoutError",
+    "JobInfo",
+    "JobOwner",
+    "JobStage",
+    "JobStatus",
     "KerasModelHubMixin",
     "MCPClient",
     "ModelCard",
@@ -792,6 +822,7 @@ __all__ = [
     "auth_switch",
     "cached_assets_path",
     "cancel_access_request",
+    "cancel_job",
     "change_discussion_status",
     "comment_discussion",
     "configure_http_backend",
@@ -803,6 +834,8 @@ __all__ = [
     "create_inference_endpoint_from_catalog",
     "create_pull_request",
     "create_repo",
+    "create_scheduled_job",
+    "create_scheduled_uv_job",
     "create_tag",
     "create_webhook",
     "dataset_info",
@@ -813,6 +846,7 @@ __all__ = [
     "delete_folder",
     "delete_inference_endpoint",
     "delete_repo",
+    "delete_scheduled_job",
     "delete_space_secret",
     "delete_space_storage",
     "delete_space_variable",
@@ -825,6 +859,7 @@ __all__ = [
     "enable_webhook",
     "export_entries_as_dduf",
     "export_folder_as_dduf",
+    "fetch_job_logs",
     "file_exists",
     "from_pretrained_fastai",
     "from_pretrained_keras",
@@ -851,12 +886,15 @@ __all__ = [
     "grant_access",
     "hf_hub_download",
     "hf_hub_url",
+    "inspect_job",
+    "inspect_scheduled_job",
     "interpreter_login",
     "list_accepted_access_requests",
     "list_collections",
     "list_datasets",
     "list_inference_catalog",
     "list_inference_endpoints",
+    "list_jobs",
     "list_lfs_files",
     "list_liked_repos",
     "list_models",
@@ -905,8 +943,11 @@ __all__ = [
     "request_space_storage",
     "restart_space",
     "resume_inference_endpoint",
+    "resume_scheduled_job",
     "revision_exists",
     "run_as_future",
+    "run_job",
+    "run_uv_job",
     "save_pretrained_keras",
     "save_torch_model",
     "save_torch_state_dict",
@@ -919,6 +960,7 @@ __all__ = [
     "split_tf_state_dict_into_shards",
     "split_torch_state_dict_into_shards",
     "super_squash_history",
+    "suspend_scheduled_job",
     "try_to_load_from_cache",
     "unlike",
     "update_collection_item",
@@ -1044,6 +1086,12 @@ if TYPE_CHECKING:  # pragma: no cover
         InferenceEndpointTimeoutError,  # noqa: F401
         InferenceEndpointType,  # noqa: F401
     )
+    from ._jobs_api import (
+        JobInfo,  # noqa: F401
+        JobOwner,  # noqa: F401
+        JobStage,  # noqa: F401
+        JobStatus,  # noqa: F401
+    )
     from ._login import (
         auth_list,  # noqa: F401
         auth_switch,  # noqa: F401
@@ -1143,6 +1191,7 @@ if TYPE_CHECKING:  # pragma: no cover
         add_space_variable,  # noqa: F401
         auth_check,  # noqa: F401
         cancel_access_request,  # noqa: F401
+        cancel_job,  # noqa: F401
         change_discussion_status,  # noqa: F401
         comment_discussion,  # noqa: F401
         create_branch,  # noqa: F401
@@ -1153,6 +1202,8 @@ if TYPE_CHECKING:  # pragma: no cover
         create_inference_endpoint_from_catalog,  # noqa: F401
         create_pull_request,  # noqa: F401
         create_repo,  # noqa: F401
+        create_scheduled_job,  # noqa: F401
+        create_scheduled_uv_job,  # noqa: F401
         create_tag,  # noqa: F401
         create_webhook,  # noqa: F401
         dataset_info,  # noqa: F401
@@ -1163,6 +1214,7 @@ if TYPE_CHECKING:  # pragma: no cover
         delete_folder,  # noqa: F401
         delete_inference_endpoint,  # noqa: F401
         delete_repo,  # noqa: F401
+        delete_scheduled_job,  # noqa: F401
         delete_space_secret,  # noqa: F401
         delete_space_storage,  # noqa: F401
         delete_space_variable,  # noqa: F401
@@ -1172,6 +1224,7 @@ if TYPE_CHECKING:  # pragma: no cover
         duplicate_space,  # noqa: F401
         edit_discussion_comment,  # noqa: F401
         enable_webhook,  # noqa: F401
+        fetch_job_logs,  # noqa: F401
         file_exists,  # noqa: F401
         get_collection,  # noqa: F401
         get_dataset_tags,  # noqa: F401
@@ -1188,11 +1241,14 @@ if TYPE_CHECKING:  # pragma: no cover
         get_user_overview,  # noqa: F401
         get_webhook,  # noqa: F401
         grant_access,  # noqa: F401
+        inspect_job,  # noqa: F401
+        inspect_scheduled_job,  # noqa: F401
         list_accepted_access_requests,  # noqa: F401
         list_collections,  # noqa: F401
         list_datasets,  # noqa: F401
         list_inference_catalog,  # noqa: F401
         list_inference_endpoints,  # noqa: F401
+        list_jobs,  # noqa: F401
         list_lfs_files,  # noqa: F401
         list_liked_repos,  # noqa: F401
         list_models,  # noqa: F401
@@ -1227,12 +1283,16 @@ if TYPE_CHECKING:  # pragma: no cover
         request_space_storage,  # noqa: F401
         restart_space,  # noqa: F401
         resume_inference_endpoint,  # noqa: F401
+        resume_scheduled_job,  # noqa: F401
         revision_exists,  # noqa: F401
         run_as_future,  # noqa: F401
+        run_job,  # noqa: F401
+        run_uv_job,  # noqa: F401
         scale_to_zero_inference_endpoint,  # noqa: F401
         set_space_sleep_time,  # noqa: F401
         space_info,  # noqa: F401
         super_squash_history,  # noqa: F401
+        suspend_scheduled_job,  # noqa: F401
         unlike,  # noqa: F401
         update_collection_item,  # noqa: F401
         update_collection_metadata,  # noqa: F401
@@ -1336,6 +1396,10 @@ if TYPE_CHECKING:  # pragma: no cover
         ImageToTextInput,  # noqa: F401
         ImageToTextOutput,  # noqa: F401
         ImageToTextParameters,  # noqa: F401
+        ImageToVideoInput,  # noqa: F401
+        ImageToVideoOutput,  # noqa: F401
+        ImageToVideoParameters,  # noqa: F401
+        ImageToVideoTargetSize,  # noqa: F401
         ObjectDetectionBoundingBox,  # noqa: F401
         ObjectDetectionInput,  # noqa: F401
         ObjectDetectionOutputElement,  # noqa: F401
